@@ -77,6 +77,17 @@ namespace Model
     GetTableBucketResult& WithCreatedAt(CreatedAtT&& value) { SetCreatedAt(std::forward<CreatedAtT>(value)); return *this;}
     ///@}
 
+    ///@{
+    /**
+     * <p>The unique identifier of the table bucket.</p>
+     */
+    inline const Aws::String& GetTableBucketId() const { return m_tableBucketId; }
+    template<typename TableBucketIdT = Aws::String>
+    void SetTableBucketId(TableBucketIdT&& value) { m_tableBucketIdHasBeenSet = true; m_tableBucketId = std::forward<TableBucketIdT>(value); }
+    template<typename TableBucketIdT = Aws::String>
+    GetTableBucketResult& WithTableBucketId(TableBucketIdT&& value) { SetTableBucketId(std::forward<TableBucketIdT>(value)); return *this;}
+    ///@}
+
     ///@{
     
     inline const Aws::String& GetRequestId() const { return m_requestId; }
@@ -99,6 +110,9 @@ namespace Model
     Aws::Utils::DateTime m_createdAt{};
     bool m_createdAtHasBeenSet = false;
 
+    Aws::String m_tableBucketId;
+    bool m_tableBucketIdHasBeenSet = false;
+
     Aws::String m_requestId;
     bool m_requestIdHasBeenSet = false;
   };
